@@ -59,13 +59,8 @@ sub register {
       my $extends = delete $args->{extends};
 
       # Localize arguments
-      my @keys  = keys %$args;
-      my $i     = 0;
-      my $stash = $self->stash;
-    START:
-      local $stash->{$keys[$i]} = $args->{$keys[$i]};
-      $i++;
-      goto START unless $i >= @keys;
+      my @keys = keys %$args;
+      local @{$self->stash}{@keys} = @{$args}{@keys};
 
       return $self->render_partial(layout => $layout, extend => $extends);
     }
